@@ -7,10 +7,15 @@ import time
 from pathlib import Path
 
 import selenium
+
+# pylint: disable=unused-import   #it is used!!!
+from selenium.webdriver.common.keys import Keys
+
 from scm_helper.config import (
     C_BASE_URL,
     C_BROWSER,
     C_CHECK_URL,
+    C_DEBUG_LEVEL,
     C_SELENIUM,
     C_SWIM_ENGLAND,
     C_TEST_ID,
@@ -23,9 +28,6 @@ from scm_helper.config import (
 from scm_helper.issue import debug
 from scm_helper.notify import interact_yesno, notify
 
-# pylint: disable=unused-import   #it is used!!!
-from selenium.webdriver.common.keys import Keys
-
 SE_COOKIES = "se_cookies.json"
 FB_COOKIES = "fb_cookies.json.enc"
 FILE_WRITE = "w"
@@ -77,7 +79,7 @@ def se_check(scm, members):
 
     except selenium.common.exceptions.NoSuchElementException:
         msg = """Please solve the 'I am not a robot', and then press enter here.
-If you cnnot solve the capture try deleting the file 'se_cookies.json' 
+If you cnnot solve the capture try deleting the file 'se_cookies.json'
 in the config directory.
 """
         interact_yesno(msg)
@@ -127,7 +129,11 @@ def fb_read_url(scm, url):
         write_cookies(browser, cookiefile, scm)
         browser.get(url)
 
-    interact_yesno("Navigate to members page (if not there) - then Click to Continue")
+    debug_config = scm.config(C_DEBUG_LEVEL)
+    if debug_config > 1:
+        interact_yesno(
+            "Navigate to members page (if not there) - then Click to Continue"
+        )
 
     scroll(browser)
 
@@ -208,7 +214,7 @@ def check_member(browser, member):
         res += f"   Category: SCM-> {mycat}, SE-> {category}\n"
 
     if current != "Current":
-        res += f"   Not current\n"
+        res += "   Not current\n"
 
     if res:
         res = f"\n{member.name} ({member.asa_number}) mismatch:\n" + res
