@@ -1,8 +1,12 @@
 """SCM Conduct."""
+import datetime
+
 from scm_helper.config import (
+    A_DATEAGREED,
     A_GUID,
     A_MEMBERS,
     C_CONDUCT,
+    C_DATE,
     C_IGNORE_GROUP,
     C_LISTS,
     C_TYPES,
@@ -13,6 +17,7 @@ from scm_helper.config import (
     CTYPE_SWIMMER,
     CTYPE_SYNCHRO,
     CTYPE_VOLUNTEER,
+    SCM_DATE_FORMAT,
     get_config,
 )
 from scm_helper.entity import Entities, Entity
@@ -67,7 +72,7 @@ class CodesOfConduct(Entities):
 
     @debug_trace(5)
     def analyse(self):
-        """Analise the conduct class."""
+        """Analyse the conduct class."""
         if get_config(self.scm, C_CONDUCT) is None:
             return
 
@@ -90,18 +95,39 @@ class Conduct(Entity):
             member.add_conduct(self)
 
     def analyse(self):
-        """Analise the conduct entry."""
+        """Analyse the conduct entry."""
         # A better way of doing this would be to add
         # the attribute to the swimmer in linkage.
         # This approach breaks the model. Oh well.
+
+        ignores = get_config(self.scm, C_CONDUCT, self.name, C_IGNORE_GROUP)
+        c_date_str = get_config(self.scm, C_CONDUCT, self.name, C_DATE)
+
+        if c_date_str is None:
+            c_date_str = "1900-01-01"
+        c_date = datetime.datetime.strptime(c_date_str, SCM_DATE_FORMAT)
+
         for member in self.data[A_MEMBERS]:
 
-            if member["DateAgreed"]:
-                continue
+            if member[A_DATEAGREED]:
+                m_date = datetime.datetime.strptime(
+                    member[A_DATEAGREED], SCM_DATE_FORMAT
+                )
+                if m_date > c_date:
+                    continue
 
             person = self.scm.members.by_guid[member[A_GUID]]
             if person.confirmed_date:  # Will get a not confirmed error later in not set
-                issue(person, E_NO_CONDUCT_DATE, self.name)
+
+                found_ignore = False
+                if ignores:
+                    for ignore in ignores:
+                        if person.find_group(ignore):
+                            found_ignore = True
+                if found_ignore:
+                    continue
+
+                issue(person, E_NO_CONDUCT_DATE, self.name, 0, person.first_group)
                 codes = get_config(self.scm, C_LISTS, C_CONDUCT)
                 if codes:
                     for code in codes:
@@ -117,7 +143,7 @@ class Conduct(Entity):
 
 # Outside of class
 def check_conduct(member, my_codes):
-    """Analise a code of conduct."""
+    """Analyse a code of conduct."""
     # pylint: disable=too-many-branches
 
     if get_config(member.scm, C_CONDUCT) is None:
