@@ -1,5 +1,6 @@
 """Configuration stuff."""
-from schema import And, Optional, Schema, SchemaError
+from schema import And, Optional, Regex, Schema, SchemaError
+
 from scm_helper.notify import notify
 from scm_helper.version import VERSION
 
@@ -86,6 +87,7 @@ A_ACTIVE = "Active"
 A_ARCHIVED = "Archived"
 A_ASA_CATEGORY = "ASACategory"
 A_ASA_NUMBER = "ASANumber"
+A_DATEAGREED = "DateAgreed"
 A_DOB = "DOB"
 A_FIRSTNAME = "Firstname"
 A_GUID = "Guid"
@@ -95,6 +97,7 @@ A_ISVOLUNTEER = "IsAVolunteer"
 A_KNOWNAS = "KnownAs"
 A_LAST_ATTENDED = "LastAttended"
 A_LASTNAME = "Lastname"
+A_MAX_MEMBERS = "MaxMembers"
 A_MEMBERS = "Members"
 A_PARENTS = "Parents"
 A_USERNAME = "Username"
@@ -122,6 +125,8 @@ C_COACHES = "coaches"
 C_CONDUCT = "conduct"
 C_CONF_DIFF = "confirmation_difference"
 C_CONFIRMATION = "confirmation"
+C_COVID = "covid"
+C_DATE = "date"
 C_DBS = "dbs"
 C_DEBUG_LEVEL = "debug_level"
 C_DOB_FORMAT = "dob_format"
@@ -153,6 +158,7 @@ C_MANDATORY = "mandatory"
 C_MAPPING = "mapping"
 C_MAX_AGE = "max_age"
 C_MAX_AGE_EOY = "max_age_eoy"
+C_MAX_SESSIONS = "max_sessions"
 C_MAX_YEAR = "max_year"
 C_MEMBERS = "members"
 C_MESSAGE = "message"
@@ -323,6 +329,7 @@ SCHEMA = Schema(
                     Optional(C_IGNORE_SWIMMER): bool,
                     Optional(C_IGNORE_UNKNOWN): bool,
                     Optional(C_MAX_AGE): int,
+                    Optional(C_MAX_SESSIONS): int,
                     Optional(C_MIN_AGE): int,
                     Optional(C_NO_CLUB_SESSIONS): bool,
                     Optional(C_NO_SESSION_ALLOWED): [group],
@@ -336,6 +343,7 @@ SCHEMA = Schema(
         Optional(C_SESSIONS): {
             Optional(C_ABSENCE): int,
             Optional(C_REGISTER): int,
+            Optional(C_COVID): conduct,
             Optional(C_SESSION): {
                 session: {
                     Optional(C_GROUPS): [group],
@@ -344,7 +352,11 @@ SCHEMA = Schema(
             },
         },
         Optional(C_CONDUCT): {
-            conduct: {C_TYPES: [member_type], Optional(C_IGNORE_GROUP): [group]}
+            conduct: {
+                C_TYPES: [member_type],
+                Optional(C_IGNORE_GROUP): [group],
+                Optional(C_DATE): Regex(r"\d\d\d\d-\d\d-\d\d"),
+            }
         },
         Optional(C_ISSUES): {
             issue: {Optional(C_MESSAGE): str, Optional(C_IGNORE_ERROR): bool}
