@@ -41,7 +41,7 @@ def create_default_config():
         return False
 
 
-DEFAULT_CONFIG = f"""
+DEFAULT_CONFIG = """
 ################################################################
 # Configuration of SCM-Helper
 #
@@ -280,7 +280,7 @@ lists:
     edit: False             # Allow script to modify generated lists
     confirmation: False     # Generate lists of non-confirmed and
                             # expired confirmation members
-#    conduct:               # Create a list of memebrs who have not signed the code of conduct
+#    conduct:               # Create a list of members who have not signed the code of conduct
 #      - "Code of Conduct Name"
 
 #     list:
